@@ -139,8 +139,6 @@ func httpUpload(client *xmpp.Client, jserver string, filePath string) string {
 		log.Fatal(err)
 	}
 	fileNameEscaped := reg.ReplaceAllString(fileName, "_")
-	//var fileNameEscaped bytes.Buffer
-	//xml.Escape(&fileNameEscaped, []byte(fileName))
 
 	// Query server for disco#items
 	id := getID()
@@ -174,7 +172,7 @@ func httpUpload(client *xmpp.Client, jserver string, filePath string) string {
 		iqDiscoInfo := <-c
 		close(c)
 		if iqDiscoInfo.Type != "result" {
-			log.Fatal("Error while disco#info query.")
+			continue
 		}
 		err = xml.Unmarshal(iqDiscoInfo.Query, &iqDiscoInfoXML)
 		if err != nil {
